---
name: Паведамленне аб памылцы
about: Раскажыце што сталася, каб дапамагчы выправіць праблему
title: ''
labels: 'bug'
assignees: ''

---

**Апісанне праблемы**
Простае і кароткае апісанне таго што сталася.

**Каб паўтарыць**
Дайце максімальна кароткі кавалак тэксту, на каторым магчыма ўбачыць памылку

**Чаканы вынік**
Караценька раскажыце што вы чакалі ўбачыць у гэтай сітуацыі.

**Асяроддзе, у каторым узнікла праблема (запоўніце наступныя палі):**
 - Версія: [напрыклад, 1.2.1]
 - OS: [напрыклад, Gobo Linux 1.3.7]
 - Версія Python: [напрыклад, 3.12]

**Дадатак**
Напішыце ўсё астатняе, што на вашую думку тычыцца гэтай праблемы. Не стрымлівайце сябе.
